@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-set -ev
+. ./lib
 
 rm -rf tmp
 mkdir tmp
@@ -17,7 +17,7 @@ $nonempty stderr
 
 >foo
 darcs add foo >stdout 2>stderr
-$empty stdout
+$nonempty stdout  # print confirmation message of added file
 $empty stderr
 
 darcs add foo >stdout 2>stderr && exit 1 || true
