@@ -9,7 +9,7 @@
 # Author: Pekka Pessi
 #
 
-set -ev
+. ./lib
 
 record="record --ignore-time --all --author X"
 
