@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 
 # Issue1977 darcs repair complains when there is no pristine.hashed directory
-set -ev
+. ./lib
 mkdir temp1
 cd temp1
 darcs init
