@@ -15,7 +15,7 @@ darcs record -am 00
 cd ..
 
 for r in a b c d; do
-  darcs put --repodir temp1 temp_$r
+  darcs get temp1 temp_$r
   cd temp_$r;
   echo $r > f
   darcs record -am "patch:$r";
