@@ -84,14 +84,15 @@ echo b > foo
 darcs record -lam BB
 echo c > foo
 darcs record -lam CC
-darcs rollback -p CC -a -m unC
+darcs rollback -p CC -a
+darcs record -am unC
 cd ..
 rm -rf temp2
 darcs get --to-patch B temp1 temp2
 cd temp2
 sleep 1 # So that rollback won't have same timestamp as get.
-darcs rollback -p BB -a -m unB
-darcs revert -a
+darcs rollback -p BB -a
+darcs record -am unB
 darcs pull -a ../temp1 2> err2
 not grep 'Error applying patch' err2
 cd ..
@@ -134,7 +135,7 @@ rm -rf temp1 temp2
 #  Error applying patch to the working directory.
 
 rm -rf tmp;
-darcs init --hashed --repodir=tmp
+darcs init --darcs-1 --repodir=tmp
 touch tmp/t.t
 cd tmp
 darcs add t.t
@@ -142,7 +143,7 @@ echo 'content'>t.t
 darcs record -am 'initial add' --ignore
 echo 'content: remote change'>t.t
 darcs record -am 'remote change' --ignore
-darcs put tmp2
+darcs get . tmp2
 cd tmp2
 darcs obliterate --last 1 --all;
 echo 'content: local change'> t.t
