@@ -26,7 +26,7 @@
 ## SOFTWARE.
 
 
-set -ev
+. ./lib
 
 rm -rf temp1 temp2 temp3 temp4 temp5
 
