@@ -2,7 +2,7 @@
 
 # From issue366 bug report
 
-set -ev
+. ./lib
 
 rm -rf temp1
 mkdir temp1
@@ -14,9 +14,9 @@ darcs add *
 darcs record -A moi -am init
 echo plim >> a
 echo plim >> b
-echo y/y/y/ | tr / \\012 | darcs revert
+echo yyyy | darcs revert
 echo ploum >> a 
-echo nyy | tr / \\012 | darcs unrevert
+echo nyyy | darcs unrevert
 
 cd ..
 rm -rf temp1
